@@ -9,7 +9,8 @@ async fn handler(mut conn: Conn<Compat<TcpStream>>) -> Conn<Compat<TcpStream>> {
         log::info!("< {}", String::from_utf8(chunk).unwrap());
     }
     conn.set_response_body("Hello world");
-    conn.response_headers().insert("Content-type", "text/plain");
+    conn.response_headers_mut()
+        .insert("Content-type", "text/plain");
     conn.set_status(200);
     conn
 }
