@@ -369,6 +369,8 @@ impl FromStr for Method {
     type Err = crate::Error;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
+        #[allow(clippy::match_str_case_mismatch)]
+        // https://github.com/rust-lang/rust-clippy/issues/7882
         match &*s.to_ascii_uppercase() {
             "ACL" => Ok(Self::Acl),
             "BASELINE-CONTROL" => Ok(Self::BaselineControl),
@@ -416,7 +418,7 @@ impl FromStr for Method {
     }
 }
 
-impl<'a> std::convert::TryFrom<&'a str> for Method {
+impl<'a> TryFrom<&'a str> for Method {
     type Error = crate::Error;
 
     fn try_from(value: &'a str) -> Result<Self, Self::Error> {
