@@ -46,9 +46,19 @@ impl<Transport> Upgrade<Transport> {
         &self.request_headers
     }
 
-    /// the http request path
+    /// the http request path up to but excluding any query component
     pub fn path(&self) -> &str {
-        &self.path
+        self.path.split('?').next().unwrap()
+    }
+
+    /**
+        retrieves the query component of the path
+    */
+    pub fn querystring(&self) -> &str {
+        match self.path.split_once('?') {
+            Some((_, query)) => query,
+            None => "",
+        }
     }
 
     /// the http method
